@@ -35,7 +35,7 @@ our @EXPORT = qw(
 
 );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 # Preloaded methods go here.
@@ -311,7 +311,7 @@ L<AWS::Signature4>
 
 =head1 AUTHOR
 
-PARTHA PRATIM SARKAR, E<lt>parthakolkata1@gmail.comE<gt>
+PARTHA PRATIM SARKAR, E<lt>partha@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
